bodewig 00/12/14 07:22:53
Modified: proposal/anteater/source/main/org/apache/ant Project.java
ProjectBuilder.java TaskManager.java
proposal/anteater/source/main/org/apache/ant/cli
CLIFrontEnd.java
Log:
Make AntEater compile.
Revision Changes Path
1.5 +6 -6
jakarta-ant/proposal/anteater/source/main/org/apache/ant/Project.java
Index: ProjectBuilder.java
===================================================================
RCS file:
/home/cvs/jakarta-ant/proposal/anteater/source/main/org/apache/ant/ProjectBuilder.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ProjectBuilder.java 2000/12/11 10:32:03 1.3
+++ ProjectBuilder.java 2000/12/14 15:22:29 1.4
@@ -26,7 +26,7 @@
/**
*
*/
- private FrontEnd frontEnd;
+ private AntFrontEnd frontEnd;
/**
*
@@ -47,7 +47,7 @@
* Creates a new project builder that will build projects for the given
* Ant.
*/
- public ProjectBuilder(FrontEnd frontEnd) {
+ public ProjectBuilder(AntFrontEnd frontEnd) {
this.frontEnd = frontEnd;
taskManager = new TaskManager(frontEnd);
parserFactory = SAXParserFactory.newInstance();
@@ -304,4 +304,4 @@
}
}
}
-}
\ No newline at end of file
+}
1.5 +7 -7
jakarta-ant/proposal/anteater/source/main/org/apache/ant/TaskManager.java
Index: TaskManager.java
===================================================================
RCS file:
/home/cvs/jakarta-ant/proposal/anteater/source/main/org/apache/ant/TaskManager.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- TaskManager.java 2000/12/11 11:10:12 1.4
+++ TaskManager.java 2000/12/14 15:22:31 1.5
@@ -26,7 +26,7 @@
/**
* FrontEnd that this TaskManager can communicate through.
*/
- private FrontEnd frontEnd;
+ private AntFrontEnd frontEnd;
/**
* Data structure where all the Class definition for all known tasks are
@@ -46,7 +46,7 @@
/**
* Creates a new TaskManager.
*/
- TaskManager(FrontEnd frontEnd) {
+ TaskManager(AntFrontEnd frontEnd) {
this.frontEnd = frontEnd;
}
@@ -104,7 +104,7 @@
*/
private void processDir(File dir) {
frontEnd.writeMessage("Scanning " + dir + " for tasks",
- FrontEnd.MSG_LEVEL_LOW);
+ AntFrontEnd.MSG_LEVEL_LOW);
File file = new File(dir, "taskdef.properties");
if (file.exists()) {
try {
@@ -121,7 +121,7 @@
try {
Class clazz = loader.loadClass(taskClass);
frontEnd.writeMessage("Got Task: " + taskName +
- clazz,
FrontEnd.MSG_LEVEL_LOW);
+ clazz,
AntFrontEnd.MSG_LEVEL_LOW);
taskClasses.put(taskName, clazz);
} catch (ClassNotFoundException cnfe) {
System.out.println("Couldn't load task: " +
taskName);
@@ -142,7 +142,7 @@
*/
private void processJar(File file) throws AntException {
frontEnd.writeMessage("Scanning " + file + " for tasks",
- FrontEnd.MSG_LEVEL_LOW);
+ AntFrontEnd.MSG_LEVEL_LOW);
try {
ZipFile zipFile = new ZipFile(file);
ZipEntry zipEntry = zipFile.getEntry("taskdef.properties");
@@ -166,7 +166,7 @@
try {
Class clazz = loader.loadClass(taskClass);
frontEnd.writeMessage("Got Task: " + taskName +
- clazz,
FrontEnd.MSG_LEVEL_LOW);
+ clazz,
AntFrontEnd.MSG_LEVEL_LOW);
taskClasses.put(taskName, clazz);
} catch (ClassNotFoundException cnfe) {
System.out.println("Couldn't load task: " +
taskName);
@@ -265,4 +265,4 @@
// hafta think about it.
}
-}
\ No newline at end of file
+}
1.5 +2 -2
jakarta-ant/proposal/anteater/source/main/org/apache/ant/cli/CLIFrontEnd.java
Index: CLIFrontEnd.java
===================================================================
RCS file:
/home/cvs/jakarta-ant/proposal/anteater/source/main/org/apache/ant/cli/CLIFrontEnd.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- CLIFrontEnd.java 2000/12/11 11:10:16 1.4
+++ CLIFrontEnd.java 2000/12/14 15:22:47 1.5
@@ -14,7 +14,7 @@
*
* @author James Duncan Davidson ([EMAIL PROTECTED])
*/
-public class CLIFrontEnd extends FrontEnd {
+public class CLIFrontEnd extends AntFrontEnd {
// -----------------------------------------------------------------
// PRIVATE MEMBERS
@@ -304,4 +304,4 @@
" will bail.";
writeMessage(msg);
}
-}
\ No newline at end of file
+}
Index: Project.java
===================================================================
RCS file:
/home/cvs/jakarta-ant/proposal/anteater/source/main/org/apache/ant/Project.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- Project.java 2000/12/11 11:10:12 1.4
+++ Project.java 2000/12/14 15:22:27 1.5
@@ -43,7 +43,7 @@
/**
* Front end that this project communicates to.
*/
- private FrontEnd frontEnd;
+ private AntFrontEnd frontEnd;
/**
* Properties of this project.
@@ -80,7 +80,7 @@
/**
* Creates a new Project object with the given FrontEnd and TaskManager
*/
- public Project(FrontEnd frontEnd, TaskManager taskManager) {
+ public Project(AntFrontEnd frontEnd, TaskManager taskManager) {
this.frontEnd = frontEnd;
this.taskManager = taskManager;
}
@@ -123,7 +123,7 @@
/**
* Gets the front end that is running this project.
*/
- public FrontEnd getFrontEnd() {
+ public AntFrontEnd getFrontEnd() {
return frontEnd;
}
@@ -198,7 +198,7 @@
/**
* Sets the front end for this project.
*/
- public void setFrontEnd(FrontEnd frontEnd) {
+ public void setFrontEnd(AntFrontEnd frontEnd) {
this.frontEnd = frontEnd;
}
@@ -233,7 +233,7 @@
*/
public void startBuild(String targetName) throws AntException {
// notify FrontEnd that we are starting a build on a project
frontEnd.notifyProjectStart(this);
@@ -283,4 +283,4 @@
public String toString() {
return "Project name=" + name;
}
-}
\ No newline at end of file
+}
1.4 +3 -3
jakarta-ant/proposal/anteater/source/main/org/apache/ant/ProjectBuilder.java
@@ -233,7 +233,7 @@
*/
public void startBuild(String targetName) throws AntException {
- // notify FrontEnd that we are starting a build on a project
+ // notify AntFrontEnd that we are starting a build on a project
frontEnd.notifyProjectStart(this);